<p align="center">


 <img  src="https://github.com/Sensei-akin/slik_python_package/blob/staging/docs/html/_images/SLIK-LOGO-BLACK-2.jpeg" width=900 height=300>

</p>

Slik-wrangler is a data to modeling tool that helps data scientists navigate the issues of basic data wrangling and preprocessing steps. The idea behind Slik is to jump-start supervised learning projects. Data scientists struggle to prepare their data for building machine learning models and all machine learning projects require data wrangling, data preprocessing, feature engineering which takes about 80% of the model building process.

Slik-wrangler has several tools that make it easy to load data of any format, clean and inspect your data. It offers a quick way to pre-process data and perform feature engineering. Building machine learning models is an inherently iterative task and data scientists face challenges of reproducing the models and productionalizing model pipelines.


This library is in very active development, so it’s not recommended for production use.

- 📖 [Documentation](https://sensei-akin.github.io/slik_python_package/html/index.html)
- 🐞 [Issue Tracker](https://github.com/AdesholaAfolabi/slik_python_package/issues) - Report bugs or suggest new features


## Contribution

We are actively seeking contribution to continue improving our open source project. Any kind of help is welcome. *Just a star on the project is a lot.* If you would like to contribute as a developer, you can join the project by [filling out this form](https://forms.gle/s88QBMXEzfaRB66s6) or by opening an issue. Any other kind of contribution, from docs to tests, is also welcome.


📣 Please fill out our [1 min survey](https://forms.gle/oGusaJK9QCTdimkg9) so that we can learn what do you think about Slik-wrangler, how you are using it, and what improvements we should make. Thank you! 👯


## Key Benefits and Advantages
### ⚒ Data Modelling with minimal coding
If you're dealing with dataframe, you can easily clean your data with one line of code. Simply say no to the boring repetitive code!

### 🚀 Ready to use
Slik-wrangler provides an easy-to-use solutions for supervised machine learning. This project tries to help make supervised machine learning more accessible for beginners, and reduce boiler plate for common tasks.

### ✨️ Modern and Intuitive Architecture
We love quality software design and aim to help others on building wonderful applications! Using Slik-wrangler will help cultivate a MLOPS mindset. With Slik, Data scientists can build model pipelines. Slik-wrangler provides explainability in the pipeline process in the form of DAG showing each step in the build process. With every build process/experiment, Slik-wrangler logs the metadata for each run
